
# Slot: neg_edge_filepath


Negative edges file path.

URI: [https://w3id.org/neat/posNegData__neg_edge_filepath](https://w3id.org/neat/posNegData__neg_edge_filepath)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [PosNegData](PosNegData.md)
